@@ -8,15 +8,12 @@ use base 'WebService::StreetMapLink';
 
 
 my %Query = ( australia => { StreetType => 'ALL' },
-              singapore => {},
             );
 
 my %Host  = ( australia => 'www.street-directory.com.au',
-              singapore => 'www.streetdirectory.com.sg',
             );
 
 my %Path  = ( australia => '/aus_new/index.cgi',
-              singapore => '/map.jsp',
             );
 
 sub Countries { keys %Query }
@@ -119,12 +116,10 @@ several host names for this service, each for a different country.
 
 =head1 COUNTRIES
 
-This subclass handles Australia and Singapore.
+This subclass handles Australia.
 
 =head1 new() PARAMETERS
 
-For Singapore, all that is required is a "postal_code".
-
 For Australia, you must provide "address", "state", and either "city"
 or "postal_code".  Some additional parsing is done on the address to
 remove the "street/ave/etc" portion, and to separate out the street
